<?php
// Exit if accessed directly.
if(!defined('ABSPATH')) exit;

if(!class_exists('RTCORE_OCDI')):

/**
 * RTCORE One Click Demo Importer Class.
 *
 * @class RTCORE_OCDI
 * @version	1.0.0
 */
class RTCORE_OCDI extends RTCORE_Base
{
    public function __construct()
    {
        parent::__construct();
    }

    public function init()
    {
        // Demo Importer
        add_filter('pt-ocdi/import_files', array($this, 'files'));

        // Before Import
        add_action('pt-ocdi/before_widgets_import', array($this, 'prepare'));

        // After Import
        add_action('pt-ocdi/after_import', array($this, 'config'), 10);
        add_action('pt-ocdi/after_import', array($this, 'activities'), 14);
        add_action('pt-ocdi/after_import', array($this, 'listings'), 15);

        // Menu Setup
        add_filter('pt-ocdi/plugin_page_setup', array($this, 'menu'));

        // Page
        add_filter('pt-ocdi/plugin_intro_text', array($this, 'intro'));
        add_filter('pt-ocdi/plugin_page_title', array($this, 'title'));
    }

    /**
     * Register Import Files for Demo Importer
     * @return array
     */
    public function files()
    {
        return array(
            array(
                'import_file_name'             => 'Sesame Demo 1',
                'categories'                   => array('Real Estate'),
                'local_import_file'            => RTCORE_ABSPATH.'/ocdi/demo1/content.xml',
                'local_import_widget_file'     => RTCORE_ABSPATH.'/ocdi/demo1/widgets.wie',
                'local_import_customizer_file' => RTCORE_ABSPATH.'/ocdi/demo1/customizer.dat',
                'local_import_redux'           => array(
                    array(
                        'file_path'   => RTCORE_ABSPATH.'/ocdi/demo1/redux.json',
                        'option_name' => 'sesame_options',
                    ),
                ),
                'import_preview_image_url'     => 'http://sesame.realtyna.com/wp-content/themes/sesame/screenshot.png',
                'preview_url'                  => 'http://sesame.realtyna.com',
            )
        );
    }

    public function prepare($demo)
    {
        $sidebars_widgets = get_option('sidebars_widgets');

        $empty_widgets = array();
        foreach($sidebars_widgets as $sidebar => $widgets) $empty_widgets[$sidebar] = array();

        update_option('sidebars_widgets', $empty_widgets);
    }

    public function config()
    {
        // Assign Menus
        $main_menu = get_term_by('name', 'Menu 1', 'nav_menu');

        set_theme_mod('nav_menu_locations', array(
            'main-menu' => $main_menu->term_id,
        ));

        // Assign front page and posts page (blog page).
        $front_page_id = get_page_by_title('Home');
        $blog_page_id = get_page_by_title('Blog');

        update_option('show_on_front', 'page');
        update_option('page_on_front', $front_page_id->ID);
        update_option('page_for_posts', $blog_page_id->ID);

        // Set Public Agent
        wpl_db::update('wpl_users', array(
            'access_public_profile' => 1
        ), 'id', 1);
    }

    public function activities()
    {
        // Listing Gallery Activity
        $JSON = wpl_db::get('`params`', 'wpl_activities', 'id', 13);

        $params = json_decode($JSON, true);
        $params['image_width'] = '350';
        $params['image_height'] = 'auto';

        wpl_db::update('wpl_activities', array(
            'params' => json_encode($params)
        ), 'id', 13);
    }

    public function listings()
    {
        if(!function_exists('_wpl_import')) return false;

        $fields = wpl_flex::get_fields('', 0, 0, '', '', "AND `enabled` >= 1 AND `kind` = 0 
			AND ((`id` IN (2,3,6,7,8,9,10,11,12,13,14,17)) 
			OR (`category` = '4' AND `type` = 'feature') 
			OR (`category` = '5' AND `type` = 'feature') 
			OR (`category` = '6' AND `type` = 'neighborhood') 
			OR (`category` = '11' AND `type` = 'tag'))");

        $post = array('command' => 'wpl_sample', 'format' => 'json');
        $data = json_decode(wpl_global::get_web_page('http://billing.realtyna.com/io/io.php', $post));
        $states = wpl_locations::get_locations(2, 254, '');

        for($i = 0; $i < 6; $i++)
        {
            $query = '';
            $pid = wpl_property::create_property_default();

            foreach($fields as $field)
            {
                if($field->type == 'listings')
                {
                    $types = wpl_global::get_listings();
                    $pos = array_rand($types);
                    $value = $types[$pos]['id'];
                }
                elseif($field->type == 'property_types')
                {
                    $types = wpl_global::get_property_types();
                    $pos = array_rand($types);
                    $value = $types[$pos]['id'];
                }
                elseif($field->type == 'price')
                {
                    $value = rand(100, 999) * 1000;
                }
                elseif($field->type == 'select')
                {
                    $params = wpl_flex::get_field_options($field->id);
                    $params = array_keys($params['params']);
                    $value = array_rand($params);
                }
                elseif($field->type == 'number')
                {
                    $value = ($field->id == 12) ? rand(1950, 2015) : rand(1, 9);
                }
                elseif($field->type == 'area')
                {
                    $value = rand(200, 999);
                }
                elseif($field->type == 'feature' or $field->type == 'tag')
                {
                    $value = rand(0, 1);
                }
                elseif($field->type == 'neighborhood')
                {
                    $value = rand(0, 1);

                    if($value == 1)
                    {
                        $dist = rand(5, 90);
                        $dist_by = rand(1, 3);
                        $query .= "`{$field->table_column}_distance` = '{$dist}', `{$field->table_column}_distance_by` = '{$dist_by}', ";
                    }
                }

                $query .= "`{$field->table_column}` = '{$value}', ";
            }

            $state = array_rand($states);
            $state_id = $states[$state]->id;
            $state_name = $states[$state]->name;
            $county = $data->counties[array_rand($data->counties)];
            $city = $data->cities[array_rand($data->cities)];
            $street = $data->streets[array_rand($data->streets)];
            $street_no = rand(500, 3000);
            $zipcode = rand(10000, 90000);

            $query .= "`field_42` = '{$street}', `street_no` = '{$street_no}', `post_code` = '{$zipcode}', ";
            $query .= "`location2_id` = '{$state_id}', `location2_name` = '{$state_name}', `location3_name` = '{$county}', `location4_name` = '{$city}'";

            wpl_db::q("UPDATE `#__wpl_properties` SET $query WHERE `id` = '$pid'");
            wpl_property::finalize($pid);

            $image = $data->images[array_rand($data->images)];
            $image_data = wpl_global::get_web_page($image);
            $image_file = wpl_global::get_upload_base_path().$pid.DS.basename($image);
            wpl_file::write($image_file, $image_data);

            $item = array('parent_id'=>$pid, 'parent_kind'=>0, 'item_type'=>'gallery', 'item_cat'=>'image', 'item_name'=>basename($image), 'creation_date'=>date("Y-m-d H:i:s"), 'index'=>0);
            wpl_items::save($item);
            wpl_property::update_numbs($pid);
        }
    }

    public function menu($setup)
    {
        $setup['page_title'] = esc_html__('Demo Import' , 'realtyna-core');
        $setup['menu_title'] = esc_html__('Demo Import' , 'realtyna-core');

        return $setup;
    }

    public function intro($intro)
    {
        return $intro;
    }

    public function title($title)
    {
        return '<h1 class="ocdi__title dashicons-before dashicons-upload">'.esc_html__('Sesame Demo Importer', 'realtyna-core').'</h1>';
    }
}

endif;